MCP request handler implementation
Provides MCP protocol request handling logic, including tool listing, tool invocation, and resource lists.
Main Structs
CratesDocsHandler: MCP handler implementing standard protocol interfaceHandlerConfig: Handler configuration class, supports merge operation
Design
Single-layer architecture with all handling logic directly in CratesDocsHandler.
Structs
- Crates
Docs Handler - MCP server handler
- Handler
Config - Handler configuration (supports merging)
- Tool
Execution Result - Tool execution result (supports different return type conversions)