LookupItemTool

Struct LookupItemTool 

pub struct LookupItemTool {
    pub crate_name: String,
    pub item_path: String,
    pub version: Option<String>,
    pub format: Option<String>,
}
查找 crate 中的特定项目工具

Fields

crate_name: String

Crate name

item_path: String

项目路径(例如 std::collections::HashMap

version: Option<String>

Version (optional, defaults to latest)

format: Option<String>

Output format: markdown, text, or html

Implementations

Source

impl LookupItemTool

pub fn tool_name() -> String

Returns the name of the tool as a String.

pub fn request_params() -> CallToolRequestParams

Returns a CallToolRequestParams initialized with the current tool’s name.

You can further customize the request by adding arguments or other attributes using the builder pattern. For example:

let args = serde_json::Map::new();
let task_meta = TaskMetadata{ttl: Some(200)}

let params: CallToolRequestParams = MyTool::request_params()
    .with_arguments(args)
    .with_task(task_meta);
Returns

A CallToolRequestParams with the tool name set.

pub fn tool() -> Tool

Constructs and returns a rust_mcp_schema::Tool instance.

The tool includes the name, description, input schema, meta, and title derived from the struct’s attributes.

Source

impl LookupItemTool