pub fn build_docs_all_items_url(
crate_name: &str,
version: Option<&str>,
) -> StringExpand description
Build the docs.rs all.html index URL for a crate.
rustdoc emits an all.html page listing every item in the crate (including
re-exports) with hrefs relative to the crate root module. It is used to
resolve items that have no stub page at the path implied by their name.